==> jc-1.4.0.tar.gz: org/xml/sax/helpers/ParserFactory.h <==
// public class org.xml.sax.helpers.ParserFactory

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 719ab4a49ff6915 org_xml_sax_helpers_ParserFactory

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_xml_sax_helpers_ParserFactory_H_
#define _JC_org_xml_sax_helpers_ParserFactory_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_org_xml_sax_Parser$object;

// Typedefs
typedef struct _jc_org_xml_sax_helpers_ParserFactory$sub_refs	_jc_org_xml_sax_helpers_ParserFactory$sub_refs;
typedef struct _jc_org_xml_sax_helpers_ParserFactory$sub_nonrefs	_jc_org_xml_sax_helpers_ParserFactory$sub_nonrefs;
typedef struct _jc_org_xml_sax_helpers_ParserFactory$refs	_jc_org_xml_sax_helpers_ParserFactory$refs;
typedef struct _jc_org_xml_sax_helpers_ParserFactory$nonrefs	_jc_org_xml_sax_helpers_ParserFactory$nonrefs;
typedef struct _jc_org_xml_sax_helpers_ParserFactory$object	_jc_org_xml_sax_helpers_ParserFactory$object;

typedef const struct _jc_org_xml_sax_helpers_ParserFactory$vmethods	_jc_org_xml_sax_helpers_ParserFactory$vmethods;
typedef const struct _jc_org_xml_sax_helpers_ParserFactory$vtable	_jc_org_xml_sax_helpers_ParserFactory$vtable;
typedef const struct _jc_org_xml_sax_helpers_ParserFactory$vtype	_jc_org_xml_sax_helpers_ParserFactory$vtype;

// Constructors
extern void _jc_org_xml_sax_helpers_ParserFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_org_xml_sax_helpers_ParserFactory$object *);

// Static methods
extern struct _jc_object *_jc_org_xml_sax_helpers_ParserFactory$method$makeParser$ce99510612f57a24(_jc_env *);
extern struct _jc_object *_jc_org_xml_sax_helpers_ParserFactory$method$makeParser$4b724de827d2b13d(_jc_env *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_org_xml_sax_helpers_ParserFactory$vmethods {
};

// Vtable
struct _jc_org_xml_sax_helpers_ParserFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_xml_sax_helpers_ParserFactory$vmethods	org_xml_sax_helpers_ParserFactory;
};

// Vtype
struct _jc_org_xml_sax_helpers_ParserFactory$vtype {
	_jc_type			type;
	_jc_org_xml_sax_helpers_ParserFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_xml_sax_helpers_ParserFactory$sub_refs {
};

// Reference instance fields (object)
struct _jc_org_xml_sax_helpers_ParserFactory$refs {
    _jc_org_xml_sax_helpers_ParserFactory$sub_refs	org_xml_sax_helpers_ParserFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_xml_sax_helpers_ParserFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_xml_sax_helpers_ParserFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_xml_sax_helpers_ParserFactory$sub_nonrefs	org_xml_sax_helpers_ParserFactory;
};

// Object instance structure
struct _jc_org_xml_sax_helpers_ParserFactory$object {
	_jc_org_xml_sax_helpers_ParserFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_org_xml_sax_helpers_ParserFactory$vtype	*vtype;
	_jc_org_xml_sax_helpers_ParserFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_xml_sax_helpers_ParserFactory$vtype _jc_org_xml_sax_helpers_ParserFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_xml_sax_helpers_ParserFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_xml_sax_helpers_ParserFactory$class_object;

#endif	/* _JC_org_xml_sax_helpers_ParserFactory_H_ */

==> jc-1.4.6.tar.gz: org/xml/sax/helpers/ParserFactory.h <==
// public class org.xml.sax.helpers.ParserFactory

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 719ab4a49ff6915 org_xml_sax_helpers_ParserFactory

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_xml_sax_helpers_ParserFactory_H_
#define _JC_org_xml_sax_helpers_ParserFactory_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_org_xml_sax_Parser$object;

// Typedefs
typedef struct _jc_org_xml_sax_helpers_ParserFactory$sub_refs	_jc_org_xml_sax_helpers_ParserFactory$sub_refs;
typedef struct _jc_org_xml_sax_helpers_ParserFactory$sub_nonrefs	_jc_org_xml_sax_helpers_ParserFactory$sub_nonrefs;
typedef struct _jc_org_xml_sax_helpers_ParserFactory$refs	_jc_org_xml_sax_helpers_ParserFactory$refs;
typedef struct _jc_org_xml_sax_helpers_ParserFactory$nonrefs	_jc_org_xml_sax_helpers_ParserFactory$nonrefs;
typedef struct _jc_org_xml_sax_helpers_ParserFactory$object	_jc_org_xml_sax_helpers_ParserFactory$object;

typedef const struct _jc_org_xml_sax_helpers_ParserFactory$vmethods	_jc_org_xml_sax_helpers_ParserFactory$vmethods;
typedef const struct _jc_org_xml_sax_helpers_ParserFactory$vtable	_jc_org_xml_sax_helpers_ParserFactory$vtable;
typedef const struct _jc_org_xml_sax_helpers_ParserFactory$vtype	_jc_org_xml_sax_helpers_ParserFactory$vtype;

// Constructors
extern void _jc_org_xml_sax_helpers_ParserFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_org_xml_sax_helpers_ParserFactory$object *) _JC_JCNI_ATTR;

// Static methods
extern struct _jc_object *_jc_org_xml_sax_helpers_ParserFactory$method$makeParser$ce99510612f57a24(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_org_xml_sax_helpers_ParserFactory$method$makeParser$4b724de827d2b13d(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_org_xml_sax_helpers_ParserFactory$vmethods {
};

// Vtable
struct _jc_org_xml_sax_helpers_ParserFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_xml_sax_helpers_ParserFactory$vmethods	org_xml_sax_helpers_ParserFactory;
};

// Vtype
struct _jc_org_xml_sax_helpers_ParserFactory$vtype {
	_jc_type			type;
	_jc_org_xml_sax_helpers_ParserFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_xml_sax_helpers_ParserFactory$sub_refs {
};

// Reference instance fields (object)
struct _jc_org_xml_sax_helpers_ParserFactory$refs {
    _jc_org_xml_sax_helpers_ParserFactory$sub_refs	org_xml_sax_helpers_ParserFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_xml_sax_helpers_ParserFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_xml_sax_helpers_ParserFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_xml_sax_helpers_ParserFactory$sub_nonrefs	org_xml_sax_helpers_ParserFactory;
};

// Object instance structure
struct _jc_org_xml_sax_helpers_ParserFactory$object {
	_jc_org_xml_sax_helpers_ParserFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_org_xml_sax_helpers_ParserFactory$vtype	*vtype;
	_jc_org_xml_sax_helpers_ParserFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_xml_sax_helpers_ParserFactory$vtype _jc_org_xml_sax_helpers_ParserFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_xml_sax_helpers_ParserFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_xml_sax_helpers_ParserFactory$class_object;

#endif	/* _JC_org_xml_sax_helpers_ParserFactory_H_ */
